@@ -23,7 +23,7 @@ _MIN_NBXMPP_VER = "7.0.0"
 _MIN_GTK_VER = "4.17.5"
 _MIN_ADW_VER = "1.7.0"
 _MIN_CAIRO_VER = "1.16.0"
-_MIN_PYGOBJECT_VER = "3.52.0"
+_MIN_PYGOBJECT_VER = "3.53.0"
 _MIN_GLIB_VER = "2.80.0"
 _MIN_PANGO_VER = "1.50.0"
 _MIN_SQLITE_VER = "3.35.0"
@@ -155,7 +155,7 @@ def _run_app() -> None:
 
     def sigint_cb(num: int, stack: FrameType | None) -> None:
         print(" SIGINT/SIGTERM received")
-        application.quit()
+        application.start_shutdown()
 
     # ^C exits the application normally
     signal.signal(signal.SIGINT, sigint_cb)
