@@ -29,7 +29,7 @@ from gajim.gtk.dropdown import GajimDropDown
 from gajim.gtk.dropdown import KeyValueItem
 from gajim.gtk.preview.geo import GeoPreviewWidget
 from gajim.gtk.preview.preview import PreviewWidget
-from gajim.gtk.widgets import GajimAppWindow
+from gajim.gtk.window import GajimAppWindow
 
 from . import util
 
@@ -57,6 +57,8 @@ class TestPreview(GajimAppWindow):
             title=__class__.__name__,
             default_width=600,
             default_height=600,
+            add_window_padding=True,
+            header_bar=True,
         )
 
         self._box = Gtk.Box(
@@ -70,12 +72,14 @@ class TestPreview(GajimAppWindow):
 
         self._preview_widget = None
 
-        drop_down = GajimDropDown(list(PREVIEW_TYPES.keys()))
+        drop_down: GajimDropDown[str] = GajimDropDown(list(PREVIEW_TYPES.keys()))
         drop_down.connect("notify::selected", self._on_preview_type_selected)
         drop_down.select_key(list(PREVIEW_TYPES.keys())[1])
         self._box.append(drop_down)
 
-    def _on_preview_type_selected(self, drop_down: GajimDropDown, *args: Any) -> None:
+    def _on_preview_type_selected(
+        self, drop_down: GajimDropDown[str], *args: Any
+    ) -> None:
         selected_type = drop_down.get_selected_item()
         assert isinstance(selected_type, KeyValueItem)
         uri_data = PREVIEW_TYPES[selected_type.key]
