@@ -17,7 +17,7 @@ function main {
 
     pip3 install --upgrade precis-i18n
     pip3 install --upgrade $(echo "$PYTHON_REQUIREMENTS" | tr ["\\n"] [" "])
-    pip3 install pygobject-stubs --no-cache-dir --config-settings=config=Gtk4,Gdk4,GtkSource5
+    pip3 install pygobject-stubs --no-cache-dir
 }
 
 main;
